package com.ruoyi.tcZz.mapper;

import java.util.List;
import com.ruoyi.tcZz.domain.TcMtlx;
import org.apache.ibatis.annotations.Param;

/**
 * 媒体类型Mapper接口
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
public interface TcMtlxMapper 
{
    /**
     * 查询媒体类型
     * 
     * @param id 媒体类型主键
     * @return 媒体类型
     */
    public TcMtlx selectTcMtlxById(Long id);

    /**
     * 查询媒体类型列表
     * 
     * @param tcMtlx 媒体类型
     * @return 媒体类型集合
     */
    public List<TcMtlx> selectTcMtlxList(TcMtlx tcMtlx);

    /**
     * 新增媒体类型
     * 
     * @param tcMtlx 媒体类型
     * @return 结果
     */
    public int insertTcMtlx(TcMtlx tcMtlx);

    /**
     * 修改媒体类型
     * 
     * @param tcMtlx 媒体类型
     * @return 结果
     */
    public int updateTcMtlx(TcMtlx tcMtlx);

    /**
     * 删除媒体类型
     * 
     * @param id 媒体类型主键
     * @return 结果
     */
    public int deleteTcMtlxById(Long id);

    /**
     * 批量删除媒体类型
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTcMtlxByIds(Long[] ids);

    /**
     * 批量启用禁用
     *
     *
     */
    public void updateByisStatus(@Param("isStatus") Integer isStatus, @Param("ids") List<String> ids);
}
